"""Ticket manager stub for backward compatibility."""


class TicketManager:
    """Stub TicketManager class for backward compatibility."""

    def create_task(self, *args, **kwargs):
        """Stub method."""
        return None

    def list_recent_tickets(self, *args, **kwargs):
        """Stub method."""
        return []

    def get_ticket(self, *args, **kwargs):
        """Stub method."""
        return None

    def update_task(self, *args, **kwargs):
        """Stub method."""
        return False

    def close_task(self, *args, **kwargs):
        """Stub method."""
        return False
